pub struct RouterChain { /* private fields */ }Expand description
Router Chain
Automatically routes to different Chains based on input content.
Implementations
Sourceimpl RouterChain
impl RouterChain
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new empty RouterChain.
Sourcepub fn add_route(
self,
name: impl Into<String>,
description: impl Into<String>,
chain: Arc<dyn BaseChain>,
) -> Self
pub fn add_route( self, name: impl Into<String>, description: impl Into<String>, chain: Arc<dyn BaseChain>, ) -> Self
Add a route destination.
Sourcepub fn add_route_with_keywords(
self,
name: impl Into<String>,
description: impl Into<String>,
chain: Arc<dyn BaseChain>,
keywords: Vec<&str>,
) -> Self
pub fn add_route_with_keywords( self, name: impl Into<String>, description: impl Into<String>, chain: Arc<dyn BaseChain>, keywords: Vec<&str>, ) -> Self
Add a route destination with a keyword list for keyword-based routing.
Sourcepub fn with_default(self, chain: Arc<dyn BaseChain>) -> Self
pub fn with_default(self, chain: Arc<dyn BaseChain>) -> Self
Set the default chain used when no route matches.
Sourcepub fn with_input_key(self, key: impl Into<String>) -> Self
pub fn with_input_key(self, key: impl Into<String>) -> Self
Set the input key.
Sourcepub fn with_verbose(self, verbose: bool) -> Self
pub fn with_verbose(self, verbose: bool) -> Self
Set verbose mode.
Sourcepub fn destinations(&self) -> &[RouteDestination]
pub fn destinations(&self) -> &[RouteDestination]
Get the route destinations.
Sourcepub fn default_chain(&self) -> Option<&Arc<dyn BaseChain>>
pub fn default_chain(&self) -> Option<&Arc<dyn BaseChain>>
Get the default chain, if set.