LLMRouterChain

Struct LLMRouterChain 

pub struct LLMRouterChain { /* private fields */ }
LLM Router Chain

Uses an LLM to intelligently determine the routing destination.

Implementations

Source

impl LLMRouterChain

pub fn new<L>(llm: L) -> Self
where L: BaseChatModel + Send + Sync + 'static, L::Error: Into<ProviderError>,

Create a new empty LLMRouterChain with the given LLM.

pub fn add_route( self, name: impl Into<String>, description: impl Into<String>, chain: Arc<dyn BaseChain>, ) -> Self

Add a route destination.

pub fn add_route_with_keywords( self, name: impl Into<String>, description: impl Into<String>, chain: Arc<dyn BaseChain>, keywords: Vec<&str>, ) -> Self

Add a route destination with a keyword list for keyword-based routing.

pub fn with_default(self, chain: Arc<dyn BaseChain>) -> Self

Set the default chain used when no route matches.

pub fn with_input_key(self, key: impl Into<String>) -> Self

Set the input key.

pub fn with_name(self, name: impl Into<String>) -> Self

Set the chain name.

pub fn with_verbose(self, verbose: bool) -> Self

Set verbose mode.

pub fn destinations(&self) -> &[RouteDestination]

Get the route destinations.

pub fn default_chain(&self) -> Option<&Arc<dyn BaseChain>>

Get the default chain, if set.