pub struct MapRerankDocumentsChain<M: BaseChatModel> { /* private fields */ }Expand description
MapRerankDocumentsChain
First calls LLM independently for each document to generate an answer and score, then ranks by relevance score and returns the highest-scoring answer.
Implementations
Sourceimpl<M: BaseChatModel> MapRerankDocumentsChain<M>
impl<M: BaseChatModel> MapRerankDocumentsChain<M>
pub fn new(llm: M) -> Self
pub fn with_map_prompt(self, template: impl Into<String>) -> Self
pub fn with_document_variable(self, name: impl Into<String>) -> Self
pub fn with_input_key(self, key: impl Into<String>) -> Self
pub fn with_output_key(self, key: impl Into<String>) -> Self
pub fn with_name(self, name: impl Into<String>) -> Self
pub fn with_verbose(self, verbose: bool) -> Self
Sourcepub fn with_top_k(self, k: usize) -> Self
pub fn with_top_k(self, k: usize) -> Self
Set the number of top results to return.
Sourcepub fn build_map_prompt(&self, context: &str, input: &str) -> String
pub fn build_map_prompt(&self, context: &str, input: &str) -> String
Build Map stage prompt.