pub struct StuffDocumentsChain<M: BaseChatModel> { /* private fields */ }Expand description
StuffDocumentsChain
Stuffs all documents into a single prompt for LLM processing. Suitable when the total document content fits within the LLM context window.
Implementations
Sourceimpl<M: BaseChatModel> StuffDocumentsChain<M>
impl<M: BaseChatModel> StuffDocumentsChain<M>
pub fn new(llm: M) -> Self
pub fn with_prompt_template(self, template: impl Into<String>) -> Self
pub fn with_document_variable(self, name: impl Into<String>) -> Self
pub fn with_input_key(self, key: impl Into<String>) -> Self
pub fn with_output_key(self, key: impl Into<String>) -> Self
pub fn with_name(self, name: impl Into<String>) -> Self
pub fn with_verbose(self, verbose: bool) -> Self
pub fn with_max_doc_length(self, max: usize) -> Self
Sourcepub fn format_documents(&self, documents: &[Document]) -> String
pub fn format_documents(&self, documents: &[Document]) -> String
Format document list into context text.
Sourcepub fn build_prompt(&self, context: &str, input: &str) -> String
pub fn build_prompt(&self, context: &str, input: &str) -> String
Build prompt.