pub struct SequentialChain { /* private fields */ }Expand description
Sequential Chain
Executes multiple chains sequentially, where the output of one chain can be used as the input of the next.
Implementations
Sourceimpl SequentialChain
impl SequentialChain
Sourcepub fn add_chain(
self,
chain: Arc<dyn BaseChain>,
input_keys: Vec<&str>,
output_keys: Vec<&str>,
) -> Self
pub fn add_chain( self, chain: Arc<dyn BaseChain>, input_keys: Vec<&str>, output_keys: Vec<&str>, ) -> Self
Add a Chain.
Arguments
chain- Chain to addinput_keys- Input keys (from global input)output_keys- Output keys (to global result)
Sourcepub fn add_chain_with_mapping(
self,
chain: Arc<dyn BaseChain>,
input_mapping: HashMap<String, String>,
output_mapping: HashMap<String, String>,
) -> Self
pub fn add_chain_with_mapping( self, chain: Arc<dyn BaseChain>, input_mapping: HashMap<String, String>, output_mapping: HashMap<String, String>, ) -> Self
Add a Chain with mapping.
Arguments
chain- Chain to addinput_mapping- Input mapping {chain_input_key: global_key}output_mapping- Output mapping {chain_output_key: global_key}